==> byzh_rc-1.1.1-py3-none-any.whl: byzh_rc/drawer/terminal/terminal.py <==

# 字体颜色
class BColor:
    RESET = "\033[0m"

    BLACK = "\033[30m"      # 黑
    RED = "\033[31m"        # 红
    GREEN = "\033[32m"      # 绿
    YELLOW = "\033[33m"     # 黄
    BLUE = "\033[34m"       # 蓝
    PURPLE = "\033[35m"     # 紫/粉
    CYAN = "\033[36m"       # 青/蓝绿
    WHITE = "\033[37m"      # 灰/银

# 背景颜色
class BBackground:
    RESET = "\033[0m"

    BLACK = "\033[40m"      # 黑
    RED = "\033[41m"        # 红
    GREEN = "\033[42m"      # 绿
    YELLOW = "\033[43m"     # 黄
    BLUE = "\033[44m"       # 蓝
    PURPLE = "\033[45m"     # 紫/粉
    CYAN = "\033[46m"       # 青/蓝绿
    WHITE = "\033[47m"      # 灰/银

# 效果
class BAppearance:
    RESET = "\033[0m"

    HIGHLIGHT = "\033[1m"  # 高亮
    LOWLIGHT = "\033[2m"   # 低亮
    UNDERLINE = "\033[4m"  # 下划线
    REVERSE = "\033[7m"    # 反显(白底黑字)


if __name__ == '__main__':
    print("以下是测试文字：")

    print("\033[0m默认文字\033[0m")
    print("\033[1m高亮文字\033[0m")
    print("\033[2m低亮文字\033[0m")
    # print("\033[3m无效文字\033[0m")
    print("\033[4m下划线文字\033[0m")
    print("\033[5m闪烁文字(无效)\033[0m")
    # print("\033[6m无效文字\033[0m")
    print("\033[7m反显文字\033[0m")
    print("\033[8m消隐文字(无效)\033[0m")

    print("\n\033[31;1m字体颜色\033[0m测试文字")
    print("\033[30m低亮黑色文字\033[0m\t\033[30;1m高亮黑色文字\033[0m")
    print("\033[31m低亮红色文字\033[0m\t\033[31;1m高亮红色文字\033[0m")
    print("\033[32m低亮绿色文字\033[0m\t\033[32;1m高亮绿色文字\033[0m")
    print("\033[33m低亮黄色文字\033[0m\t\033[33;1m高亮黄色文字\033[0m")
    print("\033[34m低亮蓝色文字\033[0m\t\033[34;1m高亮蓝色文字\033[0m")
    print("\033[35m低亮紫色文字\033[0m\t\033[35;1m高亮紫色文字\033[0m")
    print("\033[36m低亮青色文字\033[0m\t\033[36;1m高亮青色文字\033[0m")
    print("\033[37m低亮灰色文字\033[0m\t\033[37;1m高亮灰色文字\033[0m")
    # print("\033[38m测试文字\033[0m")
    # print("\033[39m测试文字\033[0m")

    print("\n\033[31;1m背景颜色\033[0m测试文字")
    print("\033[40m低亮文字黑色背景\033[0m\t\033[40;1m高亮文字黑色背景\033[0m")
    print("\033[41m低亮文字红色背景\033[0m\t\033[41;1m高亮文字红色背景\033[0m")
    print("\033[42m低亮文字绿色背景\033[0m\t\033[42;1m高亮文字绿色背景\033[0m")
    print("\033[43m低亮文字黄色背景\033[0m\t\033[43;1m高亮文字黄色背景\033[0m")
    print("\033[44m低亮文字蓝色背景\033[0m\t\033[44;1m高亮文字蓝色背景\033[0m")
    print("\033[45m低亮文字紫色背景\033[0m\t\033[45;1m高亮文字紫色背景\033[0m")
    print("\033[46m低亮文字青色背景\033[0m\t\033[46;1m高亮文字青色背景\033[0m")
    print("\033[47m低亮文字灰色背景\033[0m\t\033[47;1m高亮文字灰色背景\033[0m")
    # print("\033[48m测试文字\033[0m")
    # print("\033[49m测试文字\033[0m")

==> byzh_rc-1.3.9-py3-none-any.whl: byzh_rc/drawer/terminal/terminal.py <==
# 字体颜色
class BColor:
    RESET = "\033[0m"

    BLACK = "\033[30m"      # 黑
    RED = "\033[31m"        # 红
    GREEN = "\033[32m"      # 绿
    YELLOW = "\033[33m"     # 黄
    BLUE = "\033[34m"       # 蓝
    PURPLE = "\033[35m"     # 紫/粉
    CYAN = "\033[36m"       # 青/蓝绿
    SILVER = "\033[37m"      # 灰/银

# 背景颜色
class BBackground:
    RESET = "\033[0m"

    BLACK = "\033[40m"      # 黑
    RED = "\033[41m"        # 红
    GREEN = "\033[42m"      # 绿
    YELLOW = "\033[43m"     # 黄
    BLUE = "\033[44m"       # 蓝
    PURPLE = "\033[45m"     # 紫/粉
    CYAN = "\033[46m"       # 青/蓝绿
    SILVER = "\033[47m"      # 灰/银

# 效果
class BAppearance:
    RESET = "\033[0m"

    HIGHLIGHT = "\033[1m"  # 高亮
    LOWLIGHT = "\033[2m"   # 低亮
    UNDERLINE = "\033[4m"  # 下划线
    REVERSE = "\033[7m"    # 反显(白底黑字)


if __name__ == '__main__':
    print("以下是测试文字：")

    print("\033[0m默认文字\033[0m")
    print("\033[1m高亮文字\033[0m")
    print("\033[2m低亮文字\033[0m")
    # print("\033[3m无效文字\033[0m")
    print("\033[4m下划线文字\033[0m")
    print("\033[5m闪烁文字(无效)\033[0m")
    # print("\033[6m无效文字\033[0m")
    print("\033[7m反显文字\033[0m")
    print("\033[8m消隐文字(无效)\033[0m")

    print("\n\033[31;1m字体颜色\033[0m测试文字")
    print("\033[30m低亮黑色文字\033[0m\t\033[30;1m高亮黑色文字\033[0m")
    print("\033[31m低亮红色文字\033[0m\t\033[31;1m高亮红色文字\033[0m")
    print("\033[32m低亮绿色文字\033[0m\t\033[32;1m高亮绿色文字\033[0m")
    print("\033[33m低亮黄色文字\033[0m\t\033[33;1m高亮黄色文字\033[0m")
    print("\033[34m低亮蓝色文字\033[0m\t\033[34;1m高亮蓝色文字\033[0m")
    print("\033[35m低亮紫色文字\033[0m\t\033[35;1m高亮紫色文字\033[0m")
    print("\033[36m低亮青色文字\033[0m\t\033[36;1m高亮青色文字\033[0m")
    print("\033[37m低亮灰色文字\033[0m\t\033[37;1m高亮灰色文字\033[0m")
    # print("\033[38m测试文字\033[0m")
    # print("\033[39m测试文字\033[0m")

    print("\n\033[31;1m背景颜色\033[0m测试文字")
    print("\033[40m低亮文字黑色背景\033[0m\t\033[40;1m高亮文字黑色背景\033[0m")
    print("\033[41m低亮文字红色背景\033[0m\t\033[41;1m高亮文字红色背景\033[0m")
    print("\033[42m低亮文字绿色背景\033[0m\t\033[42;1m高亮文字绿色背景\033[0m")
    print("\033[43m低亮文字黄色背景\033[0m\t\033[43;1m高亮文字黄色背景\033[0m")
    print("\033[44m低亮文字蓝色背景\033[0m\t\033[44;1m高亮文字蓝色背景\033[0m")
    print("\033[45m低亮文字紫色背景\033[0m\t\033[45;1m高亮文字紫色背景\033[0m")
    print("\033[46m低亮文字青色背景\033[0m\t\033[46;1m高亮文字青色背景\033[0m")
    print("\033[47m低亮文字灰色背景\033[0m\t\033[47;1m高亮文字灰色背景\033[0m")
    # print("\033[48m测试文字\033[0m")
    # print("\033[49m测试文字\033[0m")
